@@ -11,6 +11,8 @@ func TestBarGraph(t *testing.T) {
 		`-m "(.+) (\d+)" -e "{$ {1} {2}}" testdata/graph.txt`,
 		`-o - -m "(.+) (\d+)" -e "{$ {1} {2}}" testdata/graph.txt`,
 		`-o - -m "(.+) (\d+)" -e "{$ {1} {2}}" --scale log10 testdata/graph.txt`,
+		`-o - -m "(.+) (\d+)" -e "{$ {1} {2}}" -s testdata/graph.txt`,
+		`-o - -m "(.+) (\d+)" -e "{$ {1} {2}}" -k testdata/graph.txt`,
 	)
 }
 
@@ -18,3 +20,8 @@ func TestBarGraphCantScaleAndStack(t *testing.T) {
 	err := testCommand(bargraphCommand(), "--stacked --scale log10 testdata/graph.txt")
 	assert.Error(t, err)
 }
+
+func TestBarGraphInlineKey(t *testing.T) {
+	err := testCommand(bargraphCommand(), "-s -k testdata/graph.txt")
+	assert.Error(t, err)
+}
