@@ -3,17 +3,20 @@ package helpers
 import (
 	"os"
 	"os/signal"
-	"rare/pkg/aggregation"
-	"rare/pkg/extractor"
-	"rare/pkg/logger"
 	"sync"
 	"time"
+
+	"github.com/zix99/rare/pkg/aggregation"
+	"github.com/zix99/rare/pkg/extractor"
+	"github.com/zix99/rare/pkg/logger"
 )
 
 // RunAggregationLoop is a helper that takes care of output sync
 // And the main async loops for you, it has two inputs (in addition to the extractor)
-//   matchProcessor - to process a match
-//   writeOutput - triggered after a delay, only if there's an update
+//
+//	matchProcessor - to process a match
+//	writeOutput - triggered after a delay, only if there's an update
+//
 // The two functions are guaranteed to never happen at the same time
 func RunAggregationLoop(ext *extractor.Extractor, aggregator aggregation.Aggregator, writeOutput func()) {
 	logger.DeferLogs()
@@ -39,7 +42,7 @@ func RunAggregationLoop(ext *extractor.Extractor, aggregator aggregation.Aggrega
 	// Processing data from extractor
 	exitSignal := make(chan os.Signal, 1)
 	signal.Notify(exitSignal, os.Interrupt)
-	reader := ext.ReadChan()
+	reader := ext.ReadSimple()
 PROCESSING_LOOP:
 	for {
 		select {
@@ -51,7 +54,7 @@ PROCESSING_LOOP:
 			}
 			outputMutex.Lock()
 			for _, match := range matchBatch {
-				aggregator.Sample(match.Extracted)
+				aggregator.Sample(match)
 			}
 			outputMutex.Unlock()
 		}
