@@ -1,6 +1,7 @@
 package cmd
 
 import (
+	"path/filepath"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -16,7 +17,7 @@ func TestEmptyWalkCommand(t *testing.T) {
 func TestWalkTestDataGlob(t *testing.T) {
 	o, e, err := testCommandCapture(walkCommand(), "testdata/*.gz")
 	assert.NoError(t, err)
-	assert.Equal(t, "testdata/log.txt.gz\n", o)
+	assert.Equal(t, filepath.Join("testdata", "log.txt.gz")+"\n", o)
 	assert.Equal(t, "Found 1 path(s)\n", e)
 }
 
@@ -24,5 +25,5 @@ func TestWalkTestDataRecursive(t *testing.T) {
 	o, e, err := testCommandCapture(walkCommand(), "-R testdata/")
 	assert.NoError(t, err)
 	assert.Contains(t, o, "log.txt")
-	assert.Equal(t, "Found 6 path(s)\n", e)
+	assert.Equal(t, "Found 7 path(s)\n", e)
 }
