@@ -2,10 +2,11 @@ package aggregation
 
 import (
 	"fmt"
-	"rare/pkg/aggregation/sorting"
 	"strconv"
 	"testing"
 
+	"github.com/zix99/rare/pkg/aggregation/sorting"
+
 	"github.com/stretchr/testify/assert"
 )
 
