@@ -1,7 +1,7 @@
 package funclib
 
 import (
-	"rare/pkg/expressions"
+	"github.com/zix99/rare/pkg/expressions"
 )
 
 func NewKeyBuilderEx(autoOptimize bool) *expressions.KeyBuilder {
