@@ -1,11 +1,12 @@
 package stdlib
 
 import (
-	"rare/pkg/expressions"
 	"strconv"
 	"testing"
 	"time"
 
+	"github.com/zix99/rare/pkg/expressions"
+
 	"github.com/araddon/dateparse"
 	"github.com/stretchr/testify/assert"
 )
