@@ -1,7 +1,7 @@
 package stdlib
 
 import (
-	. "rare/pkg/expressions" //lint:ignore ST1001 Legacy
+	. "github.com/zix99/rare/pkg/expressions" //lint:ignore ST1001 Legacy
 )
 
 func literal(s string) KeyBuilderStage {
