@@ -13,3 +13,11 @@ func (s *AlwaysMatch) FindSubmatchIndex(b []byte) []int {
 func (s *AlwaysMatch) SubexpNameTable() map[string]int {
 	return make(map[string]int)
 }
+
+func (s *AlwaysMatch) FindSubmatchIndexDst(b []byte, dst []int) []int {
+	return append(dst, 0, len(b))
+}
+
+func (s *AlwaysMatch) MatchBufSize() int {
+	return 2
+}
