@@ -1,9 +1,10 @@
 package matchers
 
 import (
-	"rare/pkg/testutil"
 	"testing"
 
+	"github.com/zix99/rare/pkg/testutil"
+
 	"github.com/stretchr/testify/assert"
 )
 
